@@ -9,9 +9,9 @@ import multiprocessing
 
 
 def _load_lib():
-    """ Load library in build/lib. """
+    """ Load library in local. """
     cur_path = os.path.dirname(os.path.abspath(os.path.expanduser(__file__)))
-    lib_path = os.path.join(cur_path, "build/")
+    lib_path = cur_path
     if platform.system() == 'Darwin':
         path_to_so_file = os.path.join(lib_path, "libmagent.dylib")
     elif platform.system() == 'Linux':
